Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(186)

Unified Diff: components/cronet/url_request_context_config_unittest.cc

Issue 2811183003: Change Cronet's "disable_ipv6" to "disable_ipv6_on_wifi" (Closed)
Patch Set: more comments Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « components/cronet/url_request_context_config.cc ('k') | net/BUILD.gn » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/cronet/url_request_context_config_unittest.cc
diff --git a/components/cronet/url_request_context_config_unittest.cc b/components/cronet/url_request_context_config_unittest.cc
index bbff7005a7929341bfffd5e619fe49bd7d18bd36..f3d9d05efda683d0bb8cc6ed9b12735f042fcbce 100644
--- a/components/cronet/url_request_context_config_unittest.cc
+++ b/components/cronet/url_request_context_config_unittest.cc
@@ -54,7 +54,7 @@ TEST(URLRequestContextConfigTest, TestExperimentalOptionParsing) {
"\"HostResolverRules\":{\"host_resolver_rules\":"
"\"MAP * 127.0.0.1\"},"
// See http://crbug.com/696569.
- "\"disable_ipv6\":true}",
+ "\"disable_ipv6_on_wifi\":true}",
// Data reduction proxy key.
"",
// Data reduction proxy.
@@ -115,9 +115,8 @@ TEST(URLRequestContextConfigTest, TestExperimentalOptionParsing) {
// Check AsyncDNS resolver is enabled.
EXPECT_TRUE(context->host_resolver()->GetDnsConfigAsValue());
- // Check IPv6 is disabled.
- EXPECT_EQ(net::ADDRESS_FAMILY_IPV4,
- context->host_resolver()->GetDefaultAddressFamily());
+ // Check IPv6 is disabled when on wifi.
+ EXPECT_TRUE(context->host_resolver()->GetNoIPv6OnWifi());
net::HostResolver::RequestInfo info(net::HostPortPair("abcde", 80));
net::AddressList addresses;
« no previous file with comments | « components/cronet/url_request_context_config.cc ('k') | net/BUILD.gn » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698